/*
* ###########################
* #      DoD:S NoNades      #
* ###########################
* 
* @author BackAgain aka sMash
* @email owner@hpherzog.de
* @version 1.5
* 
* Nade filter
* -----------
* 1  = weapon_frag_ger
* 2  = weapon_frag_us
* 4  = weapon_smoke_ger
* 8  = weapon_smoke_us
* 16 = weapon_riflegren_ger
* 32 = weapon_riflegren_us
* 
* Example filter: [No smoke granades]
* -----------------------------------
* 4 + 8 = 12
* sm_nonades_filter "12"
* 
* Example filter: [No granades]
* -----------------------------------
* 1 + 2 + 4 + 8 + 16 + 32 = 63
* sm_nonades_filter "63"
* 
*/

#include <sourcemod>
#include <sdktools>

#define PLUGIN_VERSION "1.5"
#define MAX_CVAR_LENGTH 128
#define MAX_WEAPON_LENGTH 64

new Handle:CvarEnabled
new Handle:CvarFilter
new Handle:CvarVersion
new String:WeaponNames[][] = {
	"weapon_frag_ger", "weapon_frag_us",
	"weapon_smoke_ger", "weapon_smoke_us",
	"weapon_riflegren_ger", "weapon_riflegren_us"	
}

new Filter

public Plugin:myinfo = 
{
	name = "DoD:S NoNades",
	author = "BackAgain",
	description = "Removes all the granades.",
	version = PLUGIN_VERSION,
	url = "http://www.sourcemod.net"
}

public OnPluginStart()
{
	CvarEnabled = CreateConVar("sm_nonades_enabled", "1", "Enables and disables DoD:S NoNades.",FCVAR_PLUGIN|FCVAR_REPLICATED)
	CvarFilter = CreateConVar("sm_nonades_filter", "63", "Filters granades.",FCVAR_PLUGIN|FCVAR_REPLICATED)
	CvarVersion = CreateConVar("sm_nonades_version", PLUGIN_VERSION,"DoD:S NoNades Version", FCVAR_PLUGIN|FCVAR_NOTIFY|FCVAR_REPLICATED);
	
	HookConVarChange(CvarEnabled, OnEnabledChange)
	HookConVarChange(CvarFilter, OnFilterChange)

	if(GetConVarBool(CvarEnabled)) {
		Init()
	}
}

public Init()
{
	HookEvent("player_spawn", EventPlayerSpawn)
	Filter = GetConVarInt(CvarFilter)
}

public Dispose()
{
	UnhookEvent("player_spawn", EventPlayerSpawn)
}

public OnEnabledChange(Handle:cvar, const String:oldVal[], const String:newVal[])
{
	if (StringToInt(newVal) == 1)
	{
		Init()
	}
	else
	{
		Dispose()
	}
}

public OnFilterChange(Handle:cvar, const String:oldVal[], const String:newVal[])
{
	Filter = StringToInt(newVal)
}

public Action:EventPlayerSpawn(Handle:event, const String:name[], bool:dontBroadcast)
{
	new client = GetClientOfUserId(GetEventInt(event,"userid"))
	if(client > -1) {
		RemoveNades(client)
	}
}

public bool:IsFilteredNade(ent)
{
	if(ent > -1) 
	{
		new String:entName[MAX_WEAPON_LENGTH]
		GetEdictClassname(ent,entName,MAX_WEAPON_LENGTH)
		
		for(new i=0; i < sizeof(WeaponNames); i++) 
		{
			new pow = RoundToZero(Pow(float(2),float(i)))
			if(StrEqual(entName,WeaponNames[i],false) && (pow&Filter) == pow)
			{
				return true
			}
		}
	}
	return false
}

public RemoveNades(client) {

	new ent = -1
	
	for(new i=0; i < 4; i++)
	{
		ent = GetPlayerWeaponSlot(client,i)
		if(IsFilteredNade(ent))
		{
			RemovePlayerItem(client, ent)
			RemoveEdict(ent)
		}
	}
}

